# Postbox — cron.md
> Geplante Milestones + Release-Termine

| #ID | Schedule | Milestone | Priorität | Attachment | Status |
|---|---|---|---|---|---|
| #R001 | 2026-Q2 | v1.019 — Maus-Support + urwid-Recherche | mittel | — | geplant |
| #R002 | 2026-Q3 | v2.0 — urwid-Rewrite (XED /TUI v2) | hoch | — | geplant |

<!-- Format:
| #R001 | YYYY-MM-DD / cron | Beschreibung | hoch/mittel/niedrig | attachments/cron/... | offen/aktiv/erledigt |
30 Tage vor Fälligkeit → in todo.md übertragen.
-->
